@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 package RT::Client::REST::HTTPClient;
-$RT::Client::REST::HTTPClient::VERSION = '0.57';
+$RT::Client::REST::HTTPClient::VERSION = '0.58';
 use base 'LWP::UserAgent';
 
 
@@ -47,7 +47,7 @@ RT::Client::REST::HTTPClient - Subclass LWP::UserAgent in order to support basic
 
 =head1 VERSION
 
-version 0.57
+version 0.58
 
 =head1 METHODS
 
@@ -63,43 +63,13 @@ Gets/sets basic authentication callback
 
 =back
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-=over 4
-
-=item *
-
-Abhijit Menon-Sen <ams@wiw.org>
-
-=item *
-
-Dmitri Tikhonov <dtikhonov@yahoo.com>
-
-=item *
-
-Damien "dams" Krotkine <dams@cpan.org>
-
-=item *
-
-Dean Hamstead <dean@bytefoundry.com.au>
-
-=item *
-
-Miquel Ruiz <mruiz@cpan.org>
-
-=item *
-
-JLMARTIN
-
-=item *
-
-SRVSH
-
-=back
+Dmitri Tikhonov
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Dmitri Tikhonov.
+This software is copyright (c) 2020, 2018 by Dmitri Tikhonov.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
